@@ -27,8 +27,6 @@ implement mutual exclusion manually.
 
 For a lower level API, see the :py:mod:`mlflow.tracking` module.
 """
-import sys
-
 from mlflow.version import VERSION as __version__  # pylint: disable=unused-import
 from mlflow.utils.logging_utils import _configure_mlflow_loggers
 import mlflow.tracking._model_registry.fluent
@@ -46,36 +44,76 @@ import mlflow.projects as projects  # noqa: E402
 import mlflow.tracking as tracking  # noqa: E402
 
 # model flavors
-import mlflow.fastai as fastai  # noqa: E402
-import mlflow.gluon as gluon  # noqa: E402
-import mlflow.h2o as h2o  # noqa: E402
-import mlflow.keras as keras  # noqa: E402
-import mlflow.lightgbm as lightgbm  # noqa: E402
-import mlflow.mleap as mleap  # noqa: E402
-import mlflow.onnx as onnx  # noqa: E402
-import mlflow.pyfunc as pyfunc  # noqa: E402
-import mlflow.pytorch as pytorch  # noqa: E402
-import mlflow.sklearn as sklearn  # noqa: E402
-import mlflow.spacy as spacy  # noqa: E402
-import mlflow.spark as spark  # noqa: E402
-import mlflow.statsmodels as statsmodels  # noqa: E402
-import mlflow.tensorflow as tensorflow  # noqa: E402
-import mlflow.xgboost as xgboost  # noqa: E402
-import mlflow.shap as shap  # noqa: E402
+_model_flavors_supported = []
+try:
+    # pylint: disable=unused-import
+    import mlflow.catboost as catboost  # noqa: E402
+    import mlflow.fastai as fastai  # noqa: E402
+    import mlflow.gluon as gluon  # noqa: E402
+    import mlflow.h2o as h2o  # noqa: E402
+    import mlflow.keras as keras  # noqa: E402
+    import mlflow.lightgbm as lightgbm  # noqa: E402
+    import mlflow.mleap as mleap  # noqa: E402
+    import mlflow.onnx as onnx  # noqa: E402
+    import mlflow.pyfunc as pyfunc  # noqa: E402
+    import mlflow.pytorch as pytorch  # noqa: E402
+    import mlflow.sklearn as sklearn  # noqa: E402
+    import mlflow.spacy as spacy  # noqa: E402
+    import mlflow.spark as spark  # noqa: E402
+    import mlflow.statsmodels as statsmodels  # noqa: E402
+    import mlflow.tensorflow as tensorflow  # noqa: E402
+    import mlflow.xgboost as xgboost  # noqa: E402
+    import mlflow.shap as shap  # noqa: E402
+    import mlflow.pyspark as pyspark  # noqa: E402
+    import mlflow.paddle as paddle
+
+    _model_flavors_supported = [
+        "catboost",
+        "fastai",
+        "gluon",
+        "h2o",
+        "keras",
+        "lightgbm",
+        "mleap",
+        "onnx",
+        "pyfunc",
+        "pytorch",
+        "sklearn",
+        "spacy",
+        "spark",
+        "statsmodels",
+        "tensorflow",
+        "xgboost",
+        "shap",
+        "paddle",
+    ]
+except ImportError as e:
+    # We are conditional loading these commands since the skinny client does
+    # not support them due to the pandas and numpy dependencies of MLflow Models
+    pass
 
 
 _configure_mlflow_loggers(root_module_name=__name__)
 
-if sys.version_info.major == 2:
-    warnings.warn(
-        "MLflow support for Python 2 is deprecated and will be dropped in a future "
-        "release. At that point, existing Python 2 workflows that use MLflow will "
-        "continue to work without modification, but Python 2 users will no longer "
-        "get access to the latest MLflow features and bugfixes. We recommend that "
-        "you upgrade to Python 3 - see https://docs.python.org/3/howto/pyporting.html "
-        "for a migration guide.",
-        DeprecationWarning,
-    )
+# TODO: Uncomment this block when deprecating Python 3.6 support
+# _major = 3
+# _minor = 6
+# _deprecated_version = (_major, _minor)
+# _min_supported_version = (_major, _minor + 1)
+
+# if sys.version_info[:2] == _deprecated_version:
+#     warnings.warn(
+#         "MLflow support for Python {dep_ver} is deprecated and will be dropped in "
+#         "an upcoming release. At that point, existing Python {dep_ver} workflows "
+#         "that use MLflow will continue to work without modification, but Python {dep_ver} "
+#         "users will no longer get access to the latest MLflow features and bugfixes. "
+#         "We recommend that you upgrade to Python {min_ver} or newer.".format(
+#             dep_ver=".".join(map(str, _deprecated_version)),
+#             min_ver=".".join(map(str, _min_supported_version)),
+#         ),
+#         FutureWarning,
+#         stacklevel=2,
+#     )
 
 ActiveRun = mlflow.tracking.fluent.ActiveRun
 log_param = mlflow.tracking.fluent.log_param
@@ -99,6 +137,7 @@ set_tracking_uri = tracking.set_tracking_uri
 set_registry_uri = tracking.set_registry_uri
 get_experiment = mlflow.tracking.fluent.get_experiment
 get_experiment_by_name = mlflow.tracking.fluent.get_experiment_by_name
+list_experiments = mlflow.tracking.fluent.list_experiments
 get_tracking_uri = tracking.get_tracking_uri
 get_registry_uri = tracking.get_registry_uri
 create_experiment = mlflow.tracking.fluent.create_experiment
@@ -138,6 +177,7 @@ __all__ = [
     "set_tracking_uri",
     "get_experiment",
     "get_experiment_by_name",
+    "list_experiments",
     "create_experiment",
     "set_experiment",
     "delete_experiment",
@@ -149,21 +189,4 @@ __all__ = [
     "set_registry_uri",
     "list_run_infos",
     "autolog",
-    # model flavors
-    "fastai",
-    "gluon",
-    "h2o",
-    "keras",
-    "lightgbm",
-    "mleap",
-    "onnx",
-    "pyfunc",
-    "pytorch",
-    "sklearn",
-    "spacy",
-    "spark",
-    "statsmodels",
-    "tensorflow",
-    "xgboost",
-    "shap",
-]
+] + _model_flavors_supported
