@@ -1,24 +1,27 @@
+from packaging.version import Version
 import os
 
-import gorilla
-import mxnet as mx
+import numpy as np
 import pandas as pd
 import yaml
-from mxnet import gluon
-from mxnet import sym
-from mxnet.gluon.contrib.estimator import Estimator, EpochEnd, TrainBegin, TrainEnd
-from mxnet.gluon.nn import HybridSequential
 
 import mlflow
 from mlflow import pyfunc
 from mlflow.exceptions import MlflowException
 from mlflow.models import Model
+from mlflow.models.model import MLMODEL_FILE_NAME
 from mlflow.models.signature import ModelSignature
 from mlflow.models.utils import ModelInputExample, _save_example
 from mlflow.tracking.artifact_utils import _download_artifact_from_uri
-from mlflow.utils import experimental
-from mlflow.utils.autologging_utils import try_mlflow_log
-from mlflow.utils.environment import _mlflow_conda_env
+from mlflow.utils.annotations import experimental
+from mlflow.utils.environment import _mlflow_conda_env, _log_pip_requirements
+from mlflow.utils.autologging_utils import (
+    autologging_integration,
+    safe_patch,
+    ExceptionSafeClass,
+    try_mlflow_log,
+    batch_metrics_logger,
+)
 
 FLAVOR_NAME = "gluon"
 _MODEL_SAVE_PATH = "net"
@@ -52,14 +55,21 @@ def load_model(model_uri, ctx):
         model = mlflow.gluon.load_model("runs:/" + gluon_random_data_run.info.run_id + "/model")
         model(nd.array(np.random.rand(1000, 1, 32)))
     """
+    import mxnet
+    from mxnet import gluon
+    from mxnet import sym
+
     local_model_path = _download_artifact_from_uri(artifact_uri=model_uri)
 
     model_arch_path = os.path.join(local_model_path, "data", _MODEL_SAVE_PATH) + "-symbol.json"
     model_params_path = os.path.join(local_model_path, "data", _MODEL_SAVE_PATH) + "-0000.params"
     symbol = sym.load(model_arch_path)
-    inputs = sym.var('data', dtype='float32')
+    inputs = sym.var("data", dtype="float32")
     net = gluon.SymbolBlock(symbol, inputs)
-    net.collect_params().load(model_params_path, ctx)
+    if Version(mxnet.__version__) >= Version("2.0.0"):
+        net.load_parameters(model_params_path, ctx)
+    else:
+        net.collect_params().load(model_params_path, ctx)
     return net
 
 
@@ -67,15 +77,33 @@ class _GluonModelWrapper:
     def __init__(self, gluon_model):
         self.gluon_model = gluon_model
 
-    def predict(self, df):
+    def predict(self, data):
         """
-        :param df: A Pandas DataFrame containing input array values. A DataFrame input,
-                   `df` is converted to an MXNet ndarray via `ndarray = mx.nd.array(df.values)`.
-        :return: A Pandas DataFrame containing output array values. The underlying MXNet array
-                 can be extracted from the output DataFrame as `ndarray = mx.nd.array(df.values)`.
+        :param data: Either a pandas DataFrame or a numpy array containing input array values.
+                     If the input is a DataFrame, it will be converted to an array first by a
+                     `ndarray = df.values`.
+        :return: Model predictions. If the input is a pandas.DataFrame, the predictions are returned
+                 in a pandas.DataFrame. If the input is a numpy array, the predictions are returned
+                 as either a numpy.ndarray or a plain list for hybrid models.
+
+
         """
-        ndarray = mx.nd.array(df.values)
-        return pd.DataFrame(self.gluon_model(ndarray).asnumpy())
+        import mxnet as mx
+
+        if isinstance(data, pd.DataFrame):
+            ndarray = mx.nd.array(data.values)
+            preds = self.gluon_model(ndarray)
+            if isinstance(preds, mx.ndarray.ndarray.NDArray):
+                preds = preds.asnumpy()
+            return pd.DataFrame(preds)
+        elif isinstance(data, np.ndarray):
+            ndarray = mx.nd.array(data)
+            preds = self.gluon_model(ndarray)
+            if isinstance(preds, mx.ndarray.ndarray.NDArray):
+                preds = preds.asnumpy()
+            return preds
+        else:
+            raise TypeError("Input data should be pandas.DataFrame or numpy.ndarray")
 
 
 def _load_pyfunc(path):
@@ -84,13 +112,21 @@ def _load_pyfunc(path):
 
     :param path: Local filesystem path to the MLflow Model with the ``gluon`` flavor.
     """
+    import mxnet as mx
+
     m = load_model(path, mx.current_context())
     return _GluonModelWrapper(m)
 
 
 @experimental
-def save_model(gluon_model, path, mlflow_model=None, conda_env=None,
-               signature: ModelSignature = None, input_example: ModelInputExample = None):
+def save_model(
+    gluon_model,
+    path,
+    mlflow_model=None,
+    conda_env=None,
+    signature: ModelSignature = None,
+    input_example: ModelInputExample = None,
+):
     """
     Save a Gluon model to a path on the local file system.
 
@@ -130,9 +166,10 @@ def save_model(gluon_model, path, mlflow_model=None, conda_env=None,
                         signature = infer_signature(train, predictions)
     :param input_example: (Experimental) Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
-                          model. The given example will be converted to a Pandas DataFrame and then
-                          serialized to json using the Pandas split-oriented format. Bytes are
-                          base64-encoded.
+                          model. The given example can be a Pandas DataFrame where the given
+                          example will be serialized to json using the Pandas split-oriented
+                          format, or a numpy array where the example will be serialized to json
+                          by converting it to a list. Bytes are base64-encoded.
 
 
 
@@ -173,7 +210,7 @@ def save_model(gluon_model, path, mlflow_model=None, conda_env=None,
         _save_example(mlflow_model, input_example, path)
 
     # The epoch argument of the export method does not play any role in selecting
-    # a specific epoch's paramaters, and is there only for display purposes.
+    # a specific epoch's parameters, and is there only for display purposes.
     gluon_model.export(os.path.join(data_path, _MODEL_SAVE_PATH))
     with open(os.path.join(path, "architecture.txt"), "w") as fp:
         fp.write(str(gluon_model))
@@ -185,8 +222,11 @@ def save_model(gluon_model, path, mlflow_model=None, conda_env=None,
             conda_env = yaml.safe_load(f)
     with open(os.path.join(path, conda_env_subpath), "w") as f:
         yaml.safe_dump(conda_env, stream=f, default_flow_style=False)
+
+    _log_pip_requirements(conda_env, path)
+
     pyfunc.add_to_model(mlflow_model, loader_module="mlflow.gluon", env=conda_env_subpath)
-    mlflow_model.save(os.path.join(path, "MLmodel"))
+    mlflow_model.save(os.path.join(path, MLMODEL_FILE_NAME))
 
 
 def get_default_conda_env():
@@ -194,14 +234,22 @@ def get_default_conda_env():
     :return: The default Conda environment for MLflow Models produced by calls to
              :func:`save_model()` and :func:`log_model()`.
     """
+    import mxnet as mx
+
     pip_deps = ["mxnet=={}".format(mx.__version__)]
 
     return _mlflow_conda_env(additional_pip_deps=pip_deps)
 
 
 @experimental
-def log_model(gluon_model, artifact_path, conda_env=None, registered_model_name=None,
-              signature: ModelSignature=None, input_example: ModelInputExample=None):
+def log_model(
+    gluon_model,
+    artifact_path,
+    conda_env=None,
+    registered_model_name=None,
+    signature: ModelSignature = None,
+    input_example: ModelInputExample = None,
+):
     """
     Log a Gluon model as an MLflow artifact for the current run.
 
@@ -243,9 +291,10 @@ def log_model(gluon_model, artifact_path, conda_env=None, registered_model_name=
                         signature = infer_signature(train, predictions)
     :param input_example: (Experimental) Input example provides one or several instances of valid
                           model input. The example can be used as a hint of what data to feed the
-                          model. The given example will be converted to a Pandas DataFrame and then
-                          serialized to json using the Pandas split-oriented format. Bytes are
-                          base64-encoded.
+                          model. The given example can be a Pandas DataFrame where the given
+                          example will be serialized to json using the Pandas split-oriented
+                          format, or a numpy array where the example will be serialized to json
+                          by converting it to a list. Bytes are base64-encoded.
 
 
 
@@ -272,74 +321,103 @@ def log_model(gluon_model, artifact_path, conda_env=None, registered_model_name=
             est.fit(train_data=train_data, epochs=100, val_data=validation_data)
             mlflow.gluon.log_model(net, "model")
     """
-    Model.log(artifact_path=artifact_path, flavor=mlflow.gluon, gluon_model=gluon_model,
-              conda_env=conda_env, registered_model_name=registered_model_name,
-              signature=signature, input_example=input_example)
+    Model.log(
+        artifact_path=artifact_path,
+        flavor=mlflow.gluon,
+        gluon_model=gluon_model,
+        conda_env=conda_env,
+        registered_model_name=registered_model_name,
+        signature=signature,
+        input_example=input_example,
+    )
 
 
 @experimental
-def autolog():
+@autologging_integration(FLAVOR_NAME)
+def autolog(
+    log_models=True,
+    disable=False,
+    exclusive=False,
+    disable_for_unsupported_versions=False,
+    silent=False,
+):  # pylint: disable=unused-argument
     """
-    Enable automatic logging from Gluon to MLflow.
+    Enables (or disables) and configures autologging from Gluon to MLflow.
     Logs loss and any other metrics specified in the fit
     function, and optimizer data as parameters. Model checkpoints
     are logged as artifacts to a 'models' directory.
+
+    :param log_models: If ``True``, trained models are logged as MLflow model artifacts.
+                       If ``False``, trained models are not logged.
+    :param disable: If ``True``, disables the MXNet Gluon autologging integration. If ``False``,
+                    enables the MXNet Gluon autologging integration.
+    :param exclusive: If ``True``, autologged content is not logged to user-created fluent runs.
+                      If ``False``, autologged content is logged to the active fluent run,
+                      which may be user-created.
+    :param disable_for_unsupported_versions: If ``True``, disable autologging for versions of
+                      gluon that have not been tested against this version of the MLflow client
+                      or are incompatible.
+    :param silent: If ``True``, suppress all event logs and warnings from MLflow during MXNet Gluon
+                   autologging. If ``False``, show all events and warnings during MXNet Gluon
+                   autologging.
     """
 
-    class __MLflowGluonCallback(EpochEnd, TrainEnd, TrainBegin):
-        def __init__(self):
-            self.current_epoch = 0
+    from mxnet.gluon.contrib.estimator import Estimator, EpochEnd, TrainBegin, TrainEnd
+    from mxnet.gluon.nn import HybridSequential
 
-        def epoch_end(self, estimator, *args, **kwargs):
-            logs = {}
-            for metric in estimator.train_metrics:
-                metric_name, metric_val = metric.get()
-                logs[metric_name] = metric_val
-            for metric in estimator.val_metrics:
-                metric_name, metric_val = metric.get()
-                logs[metric_name] = metric_val
-            try_mlflow_log(mlflow.log_metrics, logs, step=self.current_epoch)
-            self.current_epoch += 1
+    def getGluonCallback(metrics_logger):
+        class __MLflowGluonCallback(EpochEnd, TrainEnd, TrainBegin, metaclass=ExceptionSafeClass):
+            def __init__(self):
+                self.current_epoch = 0
 
-        def train_begin(self, estimator, *args, **kwargs):
-            try_mlflow_log(mlflow.log_param, "num_layers", len(estimator.net))
-            if estimator.max_epoch is not None:
-                try_mlflow_log(mlflow.log_param, "epochs", estimator.max_epoch)
-            if estimator.max_batch is not None:
-                try_mlflow_log(mlflow.log_param, "batches", estimator.max_batch)
-            try_mlflow_log(mlflow.log_param, "optimizer_name",
-                           type(estimator.trainer.optimizer).__name__)
-            if hasattr(estimator.trainer.optimizer, "lr"):
-                try_mlflow_log(mlflow.log_param, "learning_rate",
-                               estimator.trainer.optimizer.lr)
-            if hasattr(estimator.trainer.optimizer, "epsilon"):
-                try_mlflow_log(mlflow.log_param, "epsilon",
-                               estimator.trainer.optimizer.epsilon)
+            def epoch_end(self, estimator, *args, **kwargs):
+                logs = {}
+                for metric in estimator.train_metrics:
+                    metric_name, metric_val = metric.get()
+                    logs[metric_name] = metric_val
+                for metric in estimator.val_metrics:
+                    metric_name, metric_val = metric.get()
+                    logs[metric_name] = metric_val
+                metrics_logger.record_metrics(logs, self.current_epoch)
+                self.current_epoch += 1
 
-        def train_end(self, estimator, *args, **kwargs):
-            if isinstance(estimator.net, HybridSequential):
-                try_mlflow_log(log_model, estimator.net, artifact_path="model")
+            def train_begin(self, estimator, *args, **kwargs):
+                try_mlflow_log(mlflow.log_param, "num_layers", len(estimator.net))
+                if estimator.max_epoch is not None:
+                    try_mlflow_log(mlflow.log_param, "epochs", estimator.max_epoch)
+                if estimator.max_batch is not None:
+                    try_mlflow_log(mlflow.log_param, "batches", estimator.max_batch)
+                try_mlflow_log(
+                    mlflow.log_param, "optimizer_name", type(estimator.trainer.optimizer).__name__
+                )
+                if hasattr(estimator.trainer.optimizer, "lr"):
+                    try_mlflow_log(
+                        mlflow.log_param, "learning_rate", estimator.trainer.optimizer.lr
+                    )
+                if hasattr(estimator.trainer.optimizer, "epsilon"):
+                    try_mlflow_log(mlflow.log_param, "epsilon", estimator.trainer.optimizer.epsilon)
 
-    @gorilla.patch(Estimator)
-    def fit(self, *args, **kwargs):
-        if not mlflow.active_run():
-            auto_end_run = True
-        else:
-            auto_end_run = False
+            def train_end(self, estimator, *args, **kwargs):
+                if isinstance(estimator.net, HybridSequential) and log_models:
+                    try_mlflow_log(log_model, estimator.net, artifact_path="model")
+
+        return __MLflowGluonCallback()
+
+    def fit(original, self, *args, **kwargs):
+        # Wrap `fit` execution within a batch metrics logger context.
+        run_id = mlflow.active_run().info.run_id
+        with batch_metrics_logger(run_id) as metrics_logger:
+            mlflowGluonCallback = getGluonCallback(metrics_logger)
+            if len(args) >= 4:
+                l = list(args)
+                l[3] += [mlflowGluonCallback]
+                args = tuple(l)
+            elif "event_handlers" in kwargs:
+                kwargs["event_handlers"] += [mlflowGluonCallback]
+            else:
+                kwargs["event_handlers"] = [mlflowGluonCallback]
+            result = original(self, *args, **kwargs)
 
-        original = gorilla.get_original_attribute(Estimator, "fit")
-        if len(args) >= 4:
-            l = list(args)
-            l[3] += [__MLflowGluonCallback()]
-            args = tuple(l)
-        elif "event_handlers" in kwargs:
-            kwargs["event_handlers"] += [__MLflowGluonCallback()]
-        else:
-            kwargs["event_handlers"] = [__MLflowGluonCallback()]
-        result = original(self, *args, **kwargs)
-        if auto_end_run:
-            mlflow.end_run()
         return result
 
-    settings = gorilla.Settings(allow_hit=True, store_hit=True)
-    gorilla.apply(gorilla.Patch(Estimator, "fit", fit, settings=settings))
+    safe_patch(FLAVOR_NAME, Estimator, "fit", fit, manage_run=True)
