@@ -1,7 +1,8 @@
 import os
+from mimetypes import guess_type
 
 import posixpath
-from six.moves import urllib
+import urllib.parse
 
 from mlflow import data
 from mlflow.entities import FileInfo
@@ -12,6 +13,7 @@ from mlflow.utils.file_utils import relative_path_to_artifact_path
 
 class S3ArtifactRepository(ArtifactRepository):
     """Stores artifacts on Amazon S3."""
+
     @staticmethod
     def parse_s3_uri(uri):
         """Parse an S3 URI, returning (bucket, path)"""
@@ -19,14 +21,15 @@ class S3ArtifactRepository(ArtifactRepository):
         if parsed.scheme != "s3":
             raise Exception("Not an S3 URI: %s" % uri)
         path = parsed.path
-        if path.startswith('/'):
+        if path.startswith("/"):
             path = path[1:]
         return parsed.netloc, path
 
     @staticmethod
     def get_s3_file_upload_extra_args():
         import json
-        s3_file_upload_extra_args = os.environ.get('MLFLOW_S3_UPLOAD_EXTRA_ARGS')
+
+        s3_file_upload_extra_args = os.environ.get("MLFLOW_S3_UPLOAD_EXTRA_ARGS")
         if s3_file_upload_extra_args:
             return json.loads(s3_file_upload_extra_args)
         else:
@@ -35,26 +38,49 @@ class S3ArtifactRepository(ArtifactRepository):
     def _get_s3_client(self):
         import boto3
         from botocore.client import Config
-        s3_endpoint_url = os.environ.get('MLFLOW_S3_ENDPOINT_URL')
+
+        s3_endpoint_url = os.environ.get("MLFLOW_S3_ENDPOINT_URL")
+        ignore_tls = os.environ.get("MLFLOW_S3_IGNORE_TLS")
+
+        do_verify = True
+        if ignore_tls:
+            do_verify = ignore_tls.lower() not in ["true", "yes", "1"]
+
+        # The valid verify argument value is None/False/path to cert bundle file, See
+        # https://github.com/boto/boto3/blob/73865126cad3938ca80a2f567a1c79cb248169a7/
+        # boto3/session.py#L212
+        verify = None if do_verify else False
+
         # NOTE: If you need to specify this env variable, please file an issue at
         # https://github.com/mlflow/mlflow/issues so we know your use-case!
-        signature_version = os.environ.get('MLFLOW_EXPERIMENTAL_S3_SIGNATURE_VERSION', 's3v4')
-        return boto3.client('s3',
-                            config=Config(signature_version=signature_version),
-                            endpoint_url=s3_endpoint_url)
+        signature_version = os.environ.get("MLFLOW_EXPERIMENTAL_S3_SIGNATURE_VERSION", "s3v4")
+        return boto3.client(
+            "s3",
+            config=Config(signature_version=signature_version),
+            endpoint_url=s3_endpoint_url,
+            verify=verify,
+        )
+
+    def _upload_file(self, s3_client, local_file, bucket, key):
+        extra_args = dict()
+        guessed_type, guessed_encoding = guess_type(local_file)
+        if guessed_type is not None:
+            extra_args["ContentType"] = guessed_type
+        if guessed_encoding is not None:
+            extra_args["ContentEncoding"] = guessed_encoding
+        environ_extra_args = self.get_s3_file_upload_extra_args()
+        if environ_extra_args is not None:
+            extra_args.update(environ_extra_args)
+        s3_client.upload_file(Filename=local_file, Bucket=bucket, Key=key, ExtraArgs=extra_args)
 
     def log_artifact(self, local_file, artifact_path=None):
         (bucket, dest_path) = data.parse_s3_uri(self.artifact_uri)
         if artifact_path:
             dest_path = posixpath.join(dest_path, artifact_path)
-        dest_path = posixpath.join(
-            dest_path, os.path.basename(local_file))
-        s3_client = self._get_s3_client()
-        s3_client.upload_file(
-            Filename=local_file,
-            Bucket=bucket,
-            Key=dest_path,
-            ExtraArgs=self.get_s3_file_upload_extra_args())
+        dest_path = posixpath.join(dest_path, os.path.basename(local_file))
+        self._upload_file(
+            s3_client=self._get_s3_client(), local_file=local_file, bucket=bucket, key=dest_path
+        )
 
     def log_artifacts(self, local_dir, artifact_path=None):
         (bucket, dest_path) = data.parse_s3_uri(self.artifact_uri)
@@ -69,11 +95,12 @@ class S3ArtifactRepository(ArtifactRepository):
                 rel_path = relative_path_to_artifact_path(rel_path)
                 upload_path = posixpath.join(dest_path, rel_path)
             for f in filenames:
-                s3_client.upload_file(
-                        Filename=os.path.join(root, f),
-                        Bucket=bucket,
-                        Key=posixpath.join(upload_path, f),
-                        ExtraArgs=self.get_s3_file_upload_extra_args())
+                self._upload_file(
+                    s3_client=s3_client,
+                    local_file=os.path.join(root, f),
+                    bucket=bucket,
+                    key=posixpath.join(upload_path, f),
+                )
 
     def list_artifacts(self, path=None):
         (bucket, artifact_path) = data.parse_s3_uri(self.artifact_uri)
@@ -84,25 +111,26 @@ class S3ArtifactRepository(ArtifactRepository):
         prefix = dest_path + "/" if dest_path else ""
         s3_client = self._get_s3_client()
         paginator = s3_client.get_paginator("list_objects_v2")
-        results = paginator.paginate(Bucket=bucket, Prefix=prefix, Delimiter='/')
+        results = paginator.paginate(Bucket=bucket, Prefix=prefix, Delimiter="/")
         for result in results:
             # Subdirectories will be listed as "common prefixes" due to the way we made the request
             for obj in result.get("CommonPrefixes", []):
                 subdir_path = obj.get("Prefix")
                 self._verify_listed_object_contains_artifact_path_prefix(
-                    listed_object_path=subdir_path, artifact_path=artifact_path)
-                subdir_rel_path = posixpath.relpath(
-                    path=subdir_path, start=artifact_path)
+                    listed_object_path=subdir_path, artifact_path=artifact_path
+                )
+                subdir_rel_path = posixpath.relpath(path=subdir_path, start=artifact_path)
                 if subdir_rel_path.endswith("/"):
                     subdir_rel_path = subdir_rel_path[:-1]
                 infos.append(FileInfo(subdir_rel_path, True, None))
             # Objects listed directly will be files
-            for obj in result.get('Contents', []):
+            for obj in result.get("Contents", []):
                 file_path = obj.get("Key")
                 self._verify_listed_object_contains_artifact_path_prefix(
-                    listed_object_path=file_path, artifact_path=artifact_path)
+                    listed_object_path=file_path, artifact_path=artifact_path
+                )
                 file_rel_path = posixpath.relpath(path=file_path, start=artifact_path)
-                file_size = int(obj.get('Size'))
+                file_size = int(obj.get("Size"))
                 infos.append(FileInfo(file_rel_path, False, file_size))
         return sorted(infos, key=lambda f: f.path)
 
@@ -113,7 +141,9 @@ class S3ArtifactRepository(ArtifactRepository):
                 "The path of the listed S3 object does not begin with the specified"
                 " artifact path. Artifact path: {artifact_path}. Object path:"
                 " {object_path}.".format(
-                    artifact_path=artifact_path, object_path=listed_object_path))
+                    artifact_path=artifact_path, object_path=listed_object_path
+                )
+            )
 
     def _download_file(self, remote_file_path, local_path):
         (bucket, s3_root_path) = data.parse_s3_uri(self.artifact_uri)
@@ -122,4 +152,15 @@ class S3ArtifactRepository(ArtifactRepository):
         s3_client.download_file(bucket, s3_full_path, local_path)
 
     def delete_artifacts(self, artifact_path=None):
-        raise MlflowException('Not implemented yet')
+        (bucket, dest_path) = data.parse_s3_uri(self.artifact_uri)
+        if artifact_path:
+            dest_path = posixpath.join(dest_path, artifact_path)
+
+        s3_client = self._get_s3_client()
+        list_objects = s3_client.list_objects(Bucket=bucket, Prefix=dest_path).get("Contents", [])
+        for to_delete_obj in list_objects:
+            file_path = to_delete_obj.get("Key")
+            self._verify_listed_object_contains_artifact_path_prefix(
+                listed_object_path=file_path, artifact_path=dest_path
+            )
+            s3_client.delete_object(Bucket=bucket, Key=file_path)
