@@ -2,8 +2,10 @@ import base64
 import time
 import logging
 import json
-
 import requests
+from contextlib import contextmanager
+from requests.adapters import HTTPAdapter
+from urllib3.util import Retry
 
 from mlflow import __version__
 from mlflow.protos import databricks_pb2
@@ -42,7 +44,9 @@ def http_request(
     elif host_creds.token:
         auth_str = "Bearer %s" % host_creds.token
 
-    headers = dict(_DEFAULT_HEADERS)
+    from mlflow.tracking.request_header.registry import resolve_request_headers
+
+    headers = dict({**_DEFAULT_HEADERS, **resolve_request_headers()})
     if auth_str:
         headers["Authorization"] = auth_str
 
@@ -99,7 +103,7 @@ def _can_parse_as_json(string):
     try:
         json.loads(string)
         return True
-    except Exception:  # pylint: disable=broad-except
+    except Exception:
         return False
 
 
@@ -169,6 +173,65 @@ def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
     return response_proto
 
 
+# Response codes that generally indicate transient network failures and merit client retries,
+# based on guidance from cloud service providers
+# (https://docs.microsoft.com/en-us/azure/architecture/best-practices/retry-service-specific#general-rest-and-retry-guidelines)
+TRANSIENT_FAILURE_RESPONSE_CODES = [
+    408,  # Request Timeout
+    429,  # Too Many Requests
+    500,  # Internal Server Error
+    502,  # Bad Gateway
+    503,  # Service Unavailable
+    504,  # Gateway Timeout
+]
+
+
+@contextmanager
+def cloud_storage_http_request(method, *args, **kwargs):
+    """
+    Performs an HTTP PUT/GET request using Python's `requests` module with an automatic retry
+    policy of `retry_attempts` using exponential backoff for the following response codes:
+
+        - 408 (Request Timeout)
+        - 429 (Too Many Requests)
+        - 500 (Internal Server Error)
+        - 502 (Bad Gateway)
+        - 503 (Service Unavailable)
+        - 504 (Gateway Timeout)
+
+    :method: string of 'PUT' or 'GET', specify to do http PUT or GET
+    :args: Positional arguments to pass to `requests.Session.put/get()`
+    :kwargs: Keyword arguments to pass to `requests.Session.put/get()`
+    """
+    retry_attempts = kwargs.get("retry_attempts", 5)
+    retry_strategy = Retry(
+        total=None,
+        # Don't retry on connect-related errors raised before a request reaches a remote server
+        connect=0,
+        # Retry once for errors reading the response from a remote server
+        read=1,
+        # Limit the number of redirects to avoid infinite redirect loops
+        redirect=3,
+        # Retry a specified number of times for response codes indicating transient failures
+        status=retry_attempts,
+        status_forcelist=TRANSIENT_FAILURE_RESPONSE_CODES,
+        backoff_factor=1,
+    )
+    adapter = HTTPAdapter(max_retries=retry_strategy)
+    with requests.Session() as http:
+        http.mount("https://", adapter)
+        http.mount("http://", adapter)
+        if method.lower() == "put":
+            response = http.put(*args, **kwargs)
+        elif method.lower() == "get":
+            response = http.get(*args, **kwargs)
+        else:
+            raise ValueError("Illegal http method: " + method)
+
+        with response as r:
+            yield r
+
+
 class MlflowHostCreds(object):
     """
     Provides a hostname and optional authentication for talking to an MLflow tracking server.
